@@ -1,7 +1,13 @@
 package Devel::REPL::Profile::Minimal;
+BEGIN {
+  $Devel::REPL::Profile::Minimal::AUTHORITY = 'cpan:PHAYLON';
+}
+{
+  $Devel::REPL::Profile::Minimal::VERSION = '1.003025';
+}
 
 use Moose;
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 
 with 'Devel::REPL::Profile';
 
